@@ -404,6 +404,14 @@ class Client:
 
         return self._app_config.get(key, default)
 
+    def get_config_blob_data(self):
+        # type: (...) -> str
+        """
+        Returns the blob data defined in the device configuration.
+        """
+        request = agent_pb2.GetConfigBlobDataRequest()
+        return self.agent_stub.GetConfigBlobData(request).blob_data.data
+
     def register_config_update_callback(self, f):
         # type: (Callable) -> None
         """
